==> cython-0.29.36-py311h2bbff1b_0.tar.bz2: info/test/run_test.py <==
#  tests for cython-0.29.36-py311h2bbff1b_0 (this is a generated file);
print('===== testing package: cython-0.29.36-py311h2bbff1b_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys
import platform
is_cpython = platform.python_implementation() == 'CPython'

import Cython
import Cython.Build
import Cython.Compiler
import Cython.Compiler.Code
import Cython.Compiler.FlowControl
import Cython.Compiler.Lexicon
import Cython.Compiler.Parsing
import Cython.Compiler.Scanning
import Cython.Compiler.Visitor
import Cython.Plex.Actions
import Cython.Plex.Scanners
import Cython.Runtime
import Cython.Distutils
import Cython.Debugger
import Cython.Debugger.Tests
import Cython.Plex
import Cython.Tests
import Cython.Build.Tests
import Cython.Compiler.Tests
import Cython.Utility
import Cython.Tempita
# See: https://github.com/cython/cython/issues/5285#issuecomment-1455043943
if sys.version_info < (3, 12):
    import pyximport

if is_cpython:
    import Cython.Runtime.refnanny

import sys
import os
import subprocess
from pprint import pprint
from os.path import isfile

print('sys.executable: %r' % sys.executable)
print('sys.prefix: %r' % sys.prefix)
print('sys.version: %r' % sys.version)
print('PATH: %r' % os.environ['PATH'])
print('CWD: %r' % os.getcwd())

from distutils.spawn import find_executable
from distutils.core import setup
from distutils.extension import Extension
from Cython.Distutils import build_ext

if sys.platform != 'darwin' and find_executable('gcc'):
    sys.argv[1:] = ['build_ext', '--inplace']
    setup(name='fib',
          cmdclass={'build_ext': build_ext},
          ext_modules=[Extension("fib", ["fib.pyx"])])

    try:
        import fib
        assert fib.fib(10) == 55
    except ImportError:
        cmd = [sys.executable, '-c', 'import fib; print(fib.fib(10))']
        out = subprocess.check_output(cmd)
        assert out.decode('utf-8').strip() == '55'
#  --- run_test.py (end) ---

print('===== cython-0.29.36-py311h2bbff1b_0 OK =====');

==> cython-3.0.8-py311h2bbff1b_0.tar.bz2: info/test/run_test.py <==
#  tests for cython-3.0.8-py311h2bbff1b_0 (this is a generated file);
print('===== testing package: cython-3.0.8-py311h2bbff1b_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import sys
import platform
is_cpython = platform.python_implementation() == 'CPython'

import Cython
import Cython.Build
import Cython.Compiler
import Cython.Compiler.Code
import Cython.Compiler.FlowControl
import Cython.Compiler.Lexicon
import Cython.Compiler.Parsing
import Cython.Compiler.Scanning
import Cython.Compiler.Visitor
import Cython.Plex.Actions
import Cython.Plex.Scanners
import Cython.Runtime
import Cython.Distutils
import Cython.Debugger
import Cython.Debugger.Tests
import Cython.Plex
import Cython.Tests
import Cython.Build.Tests
import Cython.Compiler.Tests
import Cython.Utility
import Cython.Tempita

import pyximport

if is_cpython:
    import Cython.Runtime.refnanny

import sys
import os
import subprocess
from pprint import pprint

pprint('sys.executable: %r' % sys.executable)
pprint('sys.prefix: %r' % sys.prefix)
pprint('sys.version: %r' % sys.version)
pprint('PATH: %r' % os.environ['PATH'])
pprint('CWD: %r' % os.getcwd())

from setuptools import setup, Extension
from Cython.Distutils import build_ext
from shutil import which as find_executable


if find_executable('gcc') or find_executable('clang'):
    sys.argv[1:] = ['build_ext', '--inplace']
    setup(name='fib',
        cmdclass={'build_ext': build_ext},
        ext_modules=[Extension("fib", ["fib.pyx"])])

    try:
        import fib
        assert fib.fib(10) == 55
    except ImportError:
        cmd = [sys.executable, '-c', 'import fib; print(fib.fib(10))']
        out = subprocess.check_output(cmd)
        assert out.decode('utf-8').strip() == '55'
#  --- run_test.py (end) ---

print('===== cython-3.0.8-py311h2bbff1b_0 OK =====');
